;*******************************************************************************
;* TITLE	: VIDEO.S						       *
;* Function	: Video and Object Processor Routines			       *
;*									       *
;* Project #	: JAGUAR 3D pack out					       *
;*									       *
;* Programmer	: Leonard Tramiel					       *
;*		  Andrew J Burgess					       *
;*		  Rob Zdybel						       *
;*                                                                             *
;* COPYRIGHT 1992,1993 Atari U.S. Corporation				       *
;* UNATHORIZED REPRODUCTION, ADAPTATION, DISTRIBUTION, PERFORMANCE OR DISPLAY  *
;* OF THIS COMPUTER PROGRAM OR THE ASSOCIATED AUDIOVISUAL WORK IS STRICTLY     *
;* PROHIBITED.  ALL RIGHTS RESERVED.					       *
;*******************************************************************************

	.title	"VIDEO.S - video initialization and VBLANK routines"

;*=============================================================================*
;* INCLUDE FILES							       *
;*=============================================================================*

BAR_ON	EQU	0

	.include "jaguar.inc"
	.include "defs.inc"
	.include "video.inc"

;*=============================================================================*
;* EXTERNAL ROUTINES							       *
;*=============================================================================*

	.extern	CopyObjList

;*=============================================================================*
;* EXTERNAL DATA							       *
;*=============================================================================*

	.extern	framecnt		;* Count of Video Frames

;*=============================================================================*
;* PUBLIC ROUTINES							       *
;*=============================================================================*

	.globl	vblank
	.globl	vidinit
	.globl	vblinit

;*=============================================================================*
;* PUBLIC DATA								       *
;*=============================================================================*

;*=============================================================================*
;* LOCAL EQUATES							       *
;*=============================================================================*

PHRASE		EQU	8
SCRNADDR	EQU	PHRASE
OBJSIZE		EQU	3*2

;*******************************************************************************
;* SUBROUTINE AREA							       *
;*******************************************************************************

	.text

;*=============================================================================*
;* VIDINIT	- Initialize Video to 320x288 NTSC			       *
;*									       *
;* Given:								       *
;*	Control								       *
;*									       *
;* Returns:								       *
;*	Video Disabled, but ready for 320x288 NTSC			       *
;*									       *
;* Register Usage:							       *
;*	None								       *
;*									       *
;* Externals:								       *
;*	framecnt							       *
;*									       *
;*=============================================================================*

vidinit:
	clr.l	framecnt

	move.w	#n_hde,HDE
	move.w	#n_hdb1,HDB1
	move.w	#n_hdb2,HDB2

	move.w	#n_vdb,VDB
	move.w	#n_vde,VDE

	move.w	#$0,BG			; set the background color
	move.w	#$0,BORD1		; set the border color
	rts

;*=============================================================================*
;* VBLANK	- Vertical Sync Interrupt Handler			       *
;*									       *
;* Given:								       *
;*	Control								       *
;*									       *
;* Returns:								       *
;*	Object List restored for next frame				       *
;*									       *
;* Register Usage:							       *
;*	All Registers Preserved						       *
;*									       *
;* Externals:								       *
;*	CopyObjList, framecnt						       *
;*									       *
;*=============================================================================*

vblank:
	movem.l	d0-d1/a0-a1,-(sp)	; save registers

	move.w	INT1,d0
	cmp.w	#1,d0			; is this a video interrupt?
	bne	.done

	jsr	CopyObjList
	addq.l	#1,framecnt		; Count a video frame
.done:
	move.w	#$101,INT1		; enable Video interrupt and clear all others pending
	move.w	#0,INT2

	movem.l	(sp)+,d0-d1/a0-a1	; restore registers
	rte

;*=============================================================================*
;* VBLANK	- This will set up the VI (Vertical line counter Interrupt) or *
;*		  it would if the low order bit of INT1 REALLY was the VI      *
;*		  interrupt						       *
;*									       *
;* Given:								       *
;*	Control								       *
;*									       *
;* Returns:								       *
;*	VI interrupt handler enabled					       *
;*									       *
;* Register Usage:							       *
;*	All Registers Preserved						       *
;*									       *
;* Externals:								       *
;*	None								       *
;*									       *
;*=============================================================================*

vblinit:
	movem.l	d0,-(sp)		; save registers

	move.l	#vblank,LEVEL0
	move.w	#(n_vde|1),VI
	move.w	#$1,INT1

	move.w	sr,d0
	and.w	#$f8ff,d0
	move.w	d0,sr

	movem.l	(sp)+,d0		; restore registers
	rts

;*******************************************************************************
;* END OF FILE								       *
;*******************************************************************************

	.end
